| Title: | Lightweight Access to 'VDAT' Shell Commands |
|---|---|
| Description: | Provides lightweight, R-friendly syntax for 'VDAT' shell functions. |
| Authors: | Michael O'Brien [aut, cre] (ORCID: <https://orcid.org/0000-0003-1420-6395>), Benjamin L. Hlina [ctb] |
| Maintainer: | Michael O'Brien <[email protected]> |
| License: | AGPL (>= 3) |
| Version: | 0.3.1 |
| Built: | 2026-05-26 06:39:58 UTC |
| Source: | https://github.com/mhpob/rvdat |
skip_example_on_ci and skip_example_on_runiverse check the environment for
variables called "CI" and "MY_UNIVERSE", respectively, and return TRUE
if it does not exist. Used to run examples if the package is being built
locally and there's a chance that vdat.exe exists. If the package is being built on
a continuous integration platform like GitHub Actions, the "CI" variable
will be TRUE and skip_example_on_ci will return FALSE. If it is being
built locally, "CI" will be "" and skip_example_on_ci will return
TRUE. Similarly, if the package is being built on R-Universe, the
"MY_UNIVERSE" variable will have your universe's name.
skip_example_on_ci() skip_example_on_runiverse()skip_example_on_ci() skip_example_on_runiverse()
vdat.exe.Low-level interface to vdat.exe, wherein arguments are passed directly
to vdat.exe. Arguments should be character vectors, each element being
one command.
vdat_call(what = "--help", print = TRUE, pass_error = FALSE, ...)vdat_call(what = "--help", print = TRUE, pass_error = FALSE, ...)
what |
arguments passed to |
print |
logical. Defaults to TRUE. Print the output to console? |
pass_error |
logical. Defaults to FALSE. Capture and pass any error through to the user? |
... |
arguments passed to |
## Not run: # Check the help documentation vdat_call() # vdat_call("--help") # Inspect a file; multiple arguments are passed in a character vector vdat_call(c("inspect", "FILENAME")) ## End(Not run)## Not run: # Check the help documentation vdat_call() # vdat_call("--help") # Inspect a file; multiple arguments are passed in a character vector vdat_call(c("inspect", "FILENAME")) ## End(Not run)
vdat.exe to the environmental variables.Write the location of vdat.exe to the environmental variables.
vdat_here(here = Sys.getenv("RVDAT_EXE"), wine = Sys.getenv("RVDAT_WINE_EXE"))vdat_here(here = Sys.getenv("RVDAT_EXE"), wine = Sys.getenv("RVDAT_WINE_EXE"))
here |
location of |
wine |
location of |
# Auto-find vdat: vdat_here() # Provide an explicit location: vdat_here("c:/program files/innovasea/fathom connect/vdat.exe")# Auto-find vdat: vdat_here() # Provide an explicit location: vdat_here("c:/program files/innovasea/fathom connect/vdat.exe")
Return general VDAT file metadata
vdat_inspect(vdata_file, ...)vdat_inspect(vdata_file, ...)
vdata_file |
file path of VDAT file to inspect. |
... |
arguments passed to |
Return description fields ("template") of different VDAT data types and/or files
vdat_template(format = "csv.fathom", print = FALSE, ...)vdat_template(format = "csv.fathom", print = FALSE, ...)
format |
file format of the template. Currently only accepts "csv.fathom"; here for future compatibility. |
print |
logical. Defaults to FALS.E Print the output to console? |
... |
arguments passed to |
vdat convert callerInternal vdat convert caller
vdat_to( output_format = c("csv", "json"), vdata_file, outdir = getwd(), time_corrected = FALSE, quiet = FALSE, folder = FALSE, filter = NULL )vdat_to( output_format = c("csv", "json"), vdata_file, outdir = getwd(), time_corrected = FALSE, quiet = FALSE, folder = FALSE, filter = NULL )
output_format |
What is the desired output format? One of "csv" or "json". Default is "csv". |
vdata_file |
path of VDAT file to convert to CSV. |
outdir |
output directory for the created CSV files. Defaults to the current working directory. |
time_corrected |
logical. Do you want to apply the default time correction? |
quiet |
logical, defaults to FALSE. Suppress messages? |
folder |
logical, defaults to FALSE. Convert VDAT to a folder of CSVs? |
filter |
character, defaults to NULL and is currently ignored with a warning. When implemented, filtering via vdat.exe will only be available for HR3 receivers. |
Convert VDAT file to CSV
vdat_to_csv( vdata_file, outdir = getwd(), time_corrected = FALSE, quiet = FALSE, folder = FALSE, filter = NULL )vdat_to_csv( vdata_file, outdir = getwd(), time_corrected = FALSE, quiet = FALSE, folder = FALSE, filter = NULL )
vdata_file |
path of VDAT file to convert to CSV. |
outdir |
output directory for the created CSV files. Defaults to the current working directory. |
time_corrected |
logical. Do you want to apply the default time correction? |
quiet |
logical, defaults to FALSE. Suppress messages? |
folder |
logical, defaults to FALSE. Convert VDAT to a folder of CSVs? |
filter |
character, defaults to NULL and is currently ignored with a warning. When implemented, filtering via vdat.exe will only be available for HR3 receivers. |
A wrapper around vdat_to_csv that just changes folder = FALSE to
folder = TRUE.
vdat_to_folder(...)vdat_to_folder(...)
... |
arguments passed to |
Convert VDAT file to JSON
vdat_to_json( vdata_file, outdir = getwd(), time_corrected = FALSE, quiet = FALSE, filter = NULL )vdat_to_json( vdata_file, outdir = getwd(), time_corrected = FALSE, quiet = FALSE, filter = NULL )
vdata_file |
path of VDAT file to convert to JSON |
outdir |
output directory for the created JSON. Defaults to the current working directory. |
time_corrected |
logical. Do you want to apply the default time correction? |
quiet |
logical, defaults to FALSE. Suppress messages? |
filter |
character, defaults to NULL and is currently ignored with a warning. When implemented, filtering via vdat.exe will only be available for HR3 receivers. |
vdat_here.Report the version of VDAT identified in vdat_here.
vdat_version(...)vdat_version(...)
... |
arguments passed to |
vdat_version()vdat_version()